bricoleur documentation
=====================

**bricoleur** is a Python library for 'bricoleurs' who engage is the art of 'bricolage.'

Why **bricoleur**?

- Equivalent Python functions that are available online and in construction calculators.
- Develop a free open source package.

.. This is how you insert a comment; the next line is for a cross-reference (if you delete dot dot space)

.. Check out the :doc:`rst_document_name` section for further information.


.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Contents:

   install.rst
   update.rst
   release_notes.rst
   contributing.rst
   bricoleur.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
